﻿#ifndef ELECTRON_PLUGINS_IMEDIAENCRYPTDECRYPTPLUGIN_
#define ELECTRON_PLUGINS_IMEDIAENCRYPTDECRYPTPLUGIN_

#include "ITRTCPlugin.h"

typedef unsigned char uint8_t;
typedef unsigned int uint32_t;
typedef bool (*MallocMemory)(const uint8_t* oldData, uint8_t** newData, uint32_t size);

struct LiteAVBuffer {
  uint8_t* data;
  uint32_t size;
};

struct EncodedData {
  // didEncodeVideo 和 didEncodeAudio 回调时，此字段为 null;
  const char* userId;
  // 视频流类型，参考 TRTCVideoStreamType，audio 时，此字段为0
  int streamType;
  // 原始数据
  LiteAVBuffer originData;
  // 写回处理后的数据
  LiteAVBuffer processedData;
};

class IMediaEncryptDecryptPlugin : public ITRTCPlugin {
 public:
  ~IMediaEncryptDecryptPlugin() override {}

  virtual void setMallocMemoryCallback(MallocMemory callback) = 0;

  /**
   * 视频编码数据回调
   */
  virtual bool didEncodeVideo(EncodedData& data) = 0;

  /**
   * 视频解码数据回调
   */
  virtual bool willDecodeVideo(EncodedData& data) = 0;

  /**
   * 音频编码数据回调
   */
  virtual bool didEncodeAudio(EncodedData& data) = 0;

  /**
   * 音频解码数据回调
   */
  virtual bool willDecodeAudio(EncodedData& data) = 0;
};

#endif  // ELECTRON_PLUGINS_IMEDIAENCRYPTDECRYPTPLUGIN_
